rm(list = ls())

inputDirectory1 = ''
setwd(inputDirectory1)

library(dplyr) # to select top values of dataframe (top_n)
library(tidyr) # %>% function
library("Hmisc")#hmisc&ggplot2
library(lme4) #for LMM
library(car) #for function Anova()
library(emmeans) #to get letters from tukey test in LMM
library("multcomp")#for the multiple comparisons using "glht"
library(rcompanion)# nagelkerke(mod1)#Pseudo R squared
library("ggpubr")#for the ggarrange

data = read.csv('all_elevation_profiles_dat_plot.csv') #data in m, vegetation classified by zone
data$elevation_bathy_map_cm<-(data$elevation_bathy_map_cm)/100
data$elevation_bathy_map_cm<-as.numeric(data$elevation_bathy_map_cm)
data$elevation_bathy_map_cm<-as.numeric(data$elevation_bathy_map_cm)
data$veg_limits<-(data$veg_limits)/100
data$sensors<-(data$sensors)/100

data$location_ok<- factor(data$location,levels=c("zwa_mud_2017","zwa_marsh_2017","hol_marsh_2017","hol_mud_2018",
                                                 "andel_2019","uit_marsh_2019","uit_narrow_2019","uit_mud_2019","eems_perpendicular_2019"))

unique(data$location)
str(data)

install.packages('lemon')
library(lemon) #to add all the axis when using the afcet_wrap and theme_classic

#  coord_capped_cart(bottom='both', left='both', xlim=c(0,525), ylim=c(0,2.5))

# Fig. 1C
ggplot(data, aes(Distance_m, elevation_bathy_map_cm, color = factor(veg_limits)))+
  geom_path(aes(group = 1), size=1.5)+ #lines elevation + vegetaion colour
  #scale_color_manual(name= "Vegetation", values = c("yellow", "gold2", "grey","chartreuse4","tan2", "cyan4", "darkolivegreen", "springgreen4", "yellow4", "green" ))+
  scale_color_manual(name= "Vegetation", values = c("plum1", "skyblue", "grey","gold","aquamarine", "violetred1", "green3", "green1", "yellow4", "springgreen4" ))+
  geom_point(aes(x=Distance_m,y = sensors), shape=16, colour="black") +
  theme_classic()+
  theme( panel.grid.major = element_blank(),
         panel.grid.minor = element_blank(), axis.line = element_line(colour = "black"))+
  ylim(0,2.5)+
  xlim(0,525)+
  #geom_hline(yintercept=0)+
  scale_y_continuous(breaks = seq(0, 2.5, by=1), limits=c(0,2.500))+
  labs(x="Distance (m)", y="Foreshore elevation (cm NAP)") +
  facet_grid(location_ok~., scales="free")+
  coord_capped_cart(bottom='both', left='both', xlim=c(0,525), ylim=c(0,2.5))


data2 = read.csv('all_elevation_profiles_Rv3.csv') #data v3 doesn't have the point in front of the marshes of "pioneer", only marsh vs bare tidal flat in between the sensors


data2$SD_change<- as.numeric(data2$SD_change)

data2$location_sdok<- factor(data2$location_sd,levels=c("zwa_mud_2017","zwa_marsh_2017","hol_marsh_2017","hol_mud_2017",
                                                      "andel_2019","uit_marsh_2019","uit_narrow_2019","uit_mud_2019","eemshaven_2019"))

ggplot(data2, aes(x=location_sdok,y = SD_change, fill=location_sdok )) + ##plot of the most seaward sensors and most landward (marsh)
  geom_boxplot() +
  scale_fill_manual(name= "date", values = c("lightgrey", "darkolivegreen1", "darkolivegreen1", "lightgrey", "darkolivegreen1", "darkolivegreen1", "darkolivegreen1","lightgrey", "lightgrey" ))+
  theme_classic()

library(plotrix)#to calculate standard error with dplyr
df.summary9 <- data2 %>%
  group_by(location_sdok) %>%  ##Treat2 has the samples from location not separated by elevation, becuase the anova was not significant
  summarise(
    num.str = mean(SD_change, na.rm=TRUE),
    sd_num.str = sd(SD_change, na.rm=TRUE),
    se_num.str = std.error(SD_change, na.rm=TRUE)
  )
df.summary9

mod21<-aov(SD_change~location, data2)
summary(mod21) 
summary.lm(mod21)
shapiro.test(resid(mod21)) 
hist(resid(mod21))
tk21<-TukeyHSD(mod21)
tk21
test1<-emmeans(mod21, "location")
cld(test1, Letter="abcdefg") 

mod1<-lmer(SD_change ~ location + (1|runup_date), data=data2)
summary(mod1)
anova(mod1)
Anova(mod1) #high chi sq = strong correlation
hist(resid(mod1)) #normally distributed
qqmath(mod1)
shapiro.test(resid(mod1)) 
plot(mod1) # homogeneity of variance - ok
plot(resid(mod1),subset_waves$flotsam_corrected) #check linearity - ok 
summary(glht(mod1, linfct=mcp(Location="Tukey")))
test1<-emmeans(mod1, "Location")
cld(test1, Letter="abcdefg")

