############################################################################################################################################
###Vegetation analysis code from the manuscript:	Marin-Diaz B, et al - Using salt marshes for coastal protection: effective but hard to get where needed most                         ##
############################################################################################################################################

rm(list = ls())

inputDirectory1 = '/' #
setwd(inputDirectory1) #set working directory


###
# PLOTS FIELD MEASUREMENTS
###

#load field data
data = read.csv('vegetation_field_2nd_3rd_season.csv') 

library(dplyr)#to calculate means 
library(plotrix)#to calculate standard error with dplyr
#install.packages("Hmisc")
library("Hmisc")
 
#put the correct format to the "date"

#data$date= as.POSIXct(data$date)
data$H_Disc<-as.numeric(data$H_Disc)
data$H_ruler<-as.numeric(data$H_ruler)
data$Cover<-as.numeric(data$Cover)

## calculate means, standard deviations, standard errors of the vegetation cover and vegetation height measured with the ruler
data2 <- data %>%
  group_by(date, plant_code) %>%  
  summarise(
    mean_cover = mean(Cover, na.rm=TRUE),
    sd_cover = sd(Cover, na.rm=TRUE),
    se_cover = std.error(Cover, na.rm=TRUE),
    height = mean(H_ruler, na.rm=TRUE),
    sd_height = sd(H_ruler, na.rm=TRUE),
    se_height = std.error(H_ruler, na.rm=TRUE)
  )
data2

ggplot(data2, aes(x = plant_code, y = mean_cover, fill=date))  + 
  theme_classic(base_size=15)+
  geom_bar(stat="identity", position=position_dodge(), width= 0.9) +
  geom_errorbar(aes(ymin=mean_cover-sd_cover, ymax=mean_cover+sd_cover), width=.5,position=position_dodge(0.9))+
  scale_fill_manual(name= "Date", values = c("cadetblue1", "cadetblue2","cadetblue3","cadetblue4", "darkseagreen1", "darkseagreen2", "darkseagreen3"))+
  #ylim(0, 7.5)
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Date", y = "Ground cover %")
  #facet_grid(.~location)

ggplot(data2, aes(x = plant_code, y = height, fill=date))  + 
  theme_classic(base_size=15)+
  geom_bar(stat="identity", position=position_dodge(), width= 0.9) +
  geom_errorbar(aes(ymin=height-sd_height, ymax=height+sd_height), width=.5,position=position_dodge(0.9))+
  scale_fill_manual(name= "Date", values = c("cadetblue1", "cadetblue2","cadetblue3","cadetblue4", "darkseagreen1", "darkseagreen2", "darkseagreen3"))+
  #ylim(0, 7.5)
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Date", y = "Vegetation Height (m)")
#facet_grid(.~location)


###
# PLOTS LABORATORY MEASUREMENTS
###

###Load data (lengths stems, diameter, biomass)
all_stems = read.csv('stem_biomass.csv') 

all_stems$stems.broken<-as.numeric(all_stems$stems.broken)
all_stems$Stem.not.broken<-as.numeric(all_stems$Stem.not.broken)
all_stems$Middle<-as.numeric(all_stems$Middle)
all_stems$Total.length.broken.<-as.numeric(all_stems$Total.length.broken.)
all_stems$Total.length.not.broken.<-as.numeric(all_stems$Total.length.not.broken.)
all_stems$Dry.weight.g.<-as.numeric(all_stems$Dry.weight.g.)

#calculate total stem number and density in m2. sub plots where of 20x20 cm, so multiply by 25 to obtain stems per m2
all_stems$total_stems_num <- rowSums(all_stems[,c("stems.broken", "Stem.not.broken")], na.rm=TRUE) #na.rm = makes the sum even if there is a NA, for example 3+NA=3
all_stems$stem_density<-(all_stems$total_stems_num)*25

###MEANS FOR THE TABLE (MEAN, sd, se), biomass done separated below because first we need to sum the layers
## Important to use the na.rm=TRU to remove the NA, otherwise it doesn't calculate the means

df.summary3 <- all_stems %>%
  group_by(Date, plot) %>%  
  summarise(
    broken = mean(stems.broken, na.rm=TRUE),
    sd_broken = sd(stems.broken, na.rm=TRUE),
    se_broken = std.error(stems.broken, na.rm=TRUE),
    full = mean(Stem.not.broken, na.rm=TRUE),
    sd_full = sd(Stem.not.broken, na.rm=TRUE),
    se_full = std.error(Stem.not.broken, na.rm=TRUE),
    diam = mean(Middle, na.rm=TRUE),
    sd_diam = sd(Middle, na.rm=TRUE),
    se_diam = std.error(Middle, na.rm=TRUE),
    length_broken = mean(Total.length.broken., na.rm=TRUE),
    sd_length_broken = sd(Total.length.broken., na.rm=TRUE),
    se_length_broken = std.error(Total.length.broken., na.rm=TRUE),
    length_nobroken = mean(Total.length.not.broken., na.rm=TRUE),
    sd_length_nobroken = sd(Total.length.not.broken., na.rm=TRUE),
    se_length_nobroken = std.error(Total.length.not.broken., na.rm=TRUE),
    total_stem_density = mean(stem_density, na.rm=TRUE),
    sd_stem_density = sd(stem_density, na.rm=TRUE),
    se_stem_density = std.error(stem_density, na.rm=TRUE)
    )
df.summary3


##add vegetation type:

df.summary3$sp_code <- df.summary3$plot

df.summary3$sp_code[which(df.summary3$sp_code == "and1")] <- "sali_grass" 
df.summary3$sp_code[which(df.summary3$sp_code == "and2")] <- "atri" 
df.summary3$sp_code[which(df.summary3$sp_code == "and3")] <- "sali_grass"
df.summary3$sp_code[which(df.summary3$sp_code == "and4")] <- "spartina" 
df.summary3$sp_code[which(df.summary3$sp_code == "hol1")] <- "phragmites" 
df.summary3$sp_code[which(df.summary3$sp_code == "hol2")] <- "aster" 
df.summary3$sp_code[which(df.summary3$sp_code == "hol3")] <- "atri" 
df.summary3$sp_code[which(df.summary3$sp_code== "hol5")] <- "sali_anual" 
df.summary3$sp_code[which(df.summary3$sp_code== "hol6")] <- "19"
df.summary3$sp_code[which(df.summary3$sp_code == "uit1")] <- "sali_grass" 
df.summary3$sp_code[which(df.summary3$sp_code == "uit2")] <- "ely" 
df.summary3$sp_code[which(df.summary3$sp_code == "uit3")] <- "ely" 
df.summary3$sp_code[which(df.summary3$sp_code == "uit4")] <- "sali_grass" 
df.summary3$sp_code[which(df.summary3$sp_code == "uit5")] <- "sali_anual" 
df.summary3$sp_code[which(df.summary3$sp_code == "uit6")] <- "sali_grass" 
df.summary3$sp_code[which(df.summary3$sp_code == "zwa1")] <- "grass"
df.summary3$sp_code[which(df.summary3$sp_code == "zwa2")] <- "suaeda" 
df.summary3$sp_code[which(df.summary3$sp_code == "zwa3")] <- "sali_grass" 
df.summary3$sp_code[which(df.summary3$sp_code == "zwa4")] <- "spartina" 
df.summary3$sp_code[which(df.summary3$sp_code == "hol4")] <- "suaeda" 
df.summary3$sp_code[which(df.summary3$sp_code== "hol5old")] <- "19" 
df.summary3$sp_code[which(df.summary3$sp_code == "hol2_aster")] <- "aster" 
df.summary3$sp_code[which(df.summary3$sp_code == "hol4_suaeda")] <- "suaeda" 

df.summary3$location <- df.summary3$plot

df.summary3$location[which(df.summary3$location == "and1")] <- "and" 
df.summary3$location[which(df.summary3$location == "and2")] <- "and" 
df.summary3$location[which(df.summary3$location == "and3")] <- "and" 
df.summary3$location[which(df.summary3$location == "and4")] <- "and" 
df.summary3$location[which(df.summary3$location == "hol1")] <- "hol" 
df.summary3$location[which(df.summary3$location == "hol2")] <- "hol" 
df.summary3$location[which(df.summary3$location == "hol3")] <- "hol" 
df.summary3$location[which(df.summary3$location== "hol5")] <- "hol" 
df.summary3$location[which(df.summary3$location== "hol6")] <- "hol" 
df.summary3$location[which(df.summary3$location == "uit1")] <- "uit" 
df.summary3$location[which(df.summary3$location == "uit2")] <- "uit" 
df.summary3$location[which(df.summary3$location == "uit3")] <- "uit" 
df.summary3$location[which(df.summary3$location == "uit4")] <- "uit" 
df.summary3$location[which(df.summary3$location == "uit5")] <- "uit" 
df.summary3$location[which(df.summary3$location == "uit6")] <- "uit_narrow" 
df.summary3$location[which(df.summary3$location == "zwa1")] <- "zwa" 
df.summary3$location[which(df.summary3$location == "zwa2")] <- "zwa" 
df.summary3$location[which(df.summary3$location == "zwa3")] <- "zwa" 
df.summary3$location[which(df.summary3$location == "zwa4")] <- "zwa" 
df.summary3$location[which(df.summary3$location == "hol4")] <- "hol" 
df.summary3$location[which(df.summary3$location== "hol5old")] <- "hol" 
df.summary3$location[which(df.summary3$location == "hol2_aster")] <- "hol" 
df.summary3$location[which(df.summary3$location == "hol4_suaeda")] <- "hol" 


df.summary3<-df.summary3[which(df.summary3$sp_code=="aster"| 
                                 df.summary3$sp_code=="atri"|
                                 df.summary3$sp_code=="ely"|
                                 df.summary3$sp_code=="grass"|
                                 df.summary3$sp_code=="phragmites"|
                                 df.summary3$sp_code=="sali_anual"|
                                 df.summary3$sp_code=="sali_grass"|
                                 df.summary3$sp_code=="spartina"|
                                 df.summary3$sp_code=="suaeda"),]

#write.csv(df.summary3, file = "summary_lenght_stemDensity.csv")


###BOXPLOTS of diameter and stem density
## Important to use the na.rm=TRU to remove the NA, otherwise it doesn't calculate the means

df.summary4<-all_stems

# zeroes to NA
df.summary4$stem_density[which(df.summary4$stem_density == "0")] <- NA

unique(all_stems$plot)
##editar a mano paraponer variables extras y caluclar el density:

df.summary4$sp_code <- df.summary4$plot

df.summary4$sp_code[which(df.summary4$sp_code == "and1")] <- "sali_grass" 
df.summary4$sp_code[which(df.summary4$sp_code == "and2")] <- "atri" 
df.summary4$sp_code[which(df.summary4$sp_code == "and3")] <- "sali_grass" 
df.summary4$sp_code[which(df.summary4$sp_code == "and4")] <- "spartina" 
df.summary4$sp_code[which(df.summary4$sp_code == "hol1")] <- "phragmites" 
df.summary4$sp_code[which(df.summary4$sp_code == "hol2")] <- "aster" 
df.summary4$sp_code[which(df.summary4$sp_code == "hol3")] <- "atri" 
df.summary4$sp_code[which(df.summary4$sp_code== "hol5")] <- "sali_anual" 
df.summary4$sp_code[which(df.summary4$sp_code== "hol6")] <- "19" 
df.summary4$sp_code[which(df.summary4$sp_code == "uit1")] <- "sali_grass" 
df.summary4$sp_code[which(df.summary4$sp_code == "uit2")] <- "ely" 
df.summary4$sp_code[which(df.summary4$sp_code == "uit3")] <- "ely" 
df.summary4$sp_code[which(df.summary4$sp_code == "uit4")] <- "sali_grass" 
df.summary4$sp_code[which(df.summary4$sp_code == "uit5")] <- "sali_anual" 
df.summary4$sp_code[which(df.summary4$sp_code == "uit6")] <- "sali_grass" 
df.summary4$sp_code[which(df.summary4$sp_code == "zwa1")] <- "grass" 
df.summary4$sp_code[which(df.summary4$sp_code == "zwa2")] <- "suaeda" 
df.summary4$sp_code[which(df.summary4$sp_code == "zwa3")] <- "sali_grass" 
df.summary4$sp_code[which(df.summary4$sp_code == "zwa4")] <- "spartina" 
df.summary4$sp_code[which(df.summary4$sp_code == "hol4")] <- "suaeda" 
df.summary4$sp_code[which(df.summary4$sp_code== "hol5old")] <- "19" 
df.summary4$sp_code[which(df.summary4$sp_code == "hol2_aster")] <- "aster" 
df.summary4$sp_code[which(df.summary4$sp_code == "hol4_suaeda")] <- "suaeda" 

df.summary4$location <- df.summary4$plot

df.summary4$location[which(df.summary4$location == "and1")] <- "and" 
df.summary4$location[which(df.summary4$location == "and2")] <- "and" 
df.summary4$location[which(df.summary4$location == "and3")] <- "and" 
df.summary4$location[which(df.summary4$location == "and4")] <- "and" 
df.summary4$location[which(df.summary4$location == "hol1")] <- "hol" 
df.summary4$location[which(df.summary4$location == "hol2")] <- "hol" 
df.summary4$location[which(df.summary4$location == "hol3")] <- "hol" 
df.summary4$location[which(df.summary4$location== "hol5")] <- "hol" 
df.summary4$location[which(df.summary4$location== "hol6")] <- "hol" 
df.summary4$location[which(df.summary4$location == "uit1")] <- "uit" 
df.summary4$location[which(df.summary4$location == "uit2")] <- "uit" 
df.summary4$location[which(df.summary4$location == "uit3")] <- "uit" 
df.summary4$location[which(df.summary4$location == "uit4")] <- "uit" 
df.summary4$location[which(df.summary4$location == "uit5")] <- "uit" 
df.summary4$location[which(df.summary4$location == "uit6")] <- "uit_narrow" 
df.summary4$location[which(df.summary4$location == "zwa1")] <- "zwa" 
df.summary4$location[which(df.summary4$location == "zwa2")] <- "zwa" 
df.summary4$location[which(df.summary4$location == "zwa3")] <- "zwa" 
df.summary4$location[which(df.summary4$location == "zwa4")] <- "zwa" 
df.summary4$location[which(df.summary4$location == "hol4")] <- "hol" 
df.summary4$location[which(df.summary4$location== "hol5old")] <- "hol" 
df.summary4$location[which(df.summary4$location == "hol2_aster")] <- "hol" 
df.summary4$location[which(df.summary4$location == "hol4_suaeda")] <- "hol" 

#select the top layer of the vegetation (so remove Hol2_pucci and Hol4_pucci)

df.summary4<-df.summary4[which(df.summary4$sp_code=="aster"| 
                                 df.summary4$sp_code=="atri"|
                                 df.summary4$sp_code=="ely"|
                                 df.summary4$sp_code=="grass"|
                                 df.summary4$sp_code=="phragmites"|
                                 df.summary4$sp_code=="sali_anual"|
                                 df.summary4$sp_code=="sali_grass"|
                                 df.summary4$sp_code=="spartina"|
                                 df.summary4$sp_code=="suaeda"),]

# means and standard error to do barplots with error bars
df.summary7 <- df.summary4 %>%
  group_by(Date, sp_code) %>%  
  summarise(
    broken = mean(stems.broken, na.rm=TRUE),
    sd_broken = sd(stems.broken, na.rm=TRUE),
    se_broken = std.error(stems.broken, na.rm=TRUE),
    full = mean(Stem.not.broken, na.rm=TRUE),
    sd_full = sd(Stem.not.broken, na.rm=TRUE),
    se_full = std.error(Stem.not.broken, na.rm=TRUE),
    diam = mean(Middle, na.rm=TRUE),
    sd_diam = sd(Middle, na.rm=TRUE),
    se_diam = std.error(Middle, na.rm=TRUE),
    length_broken = mean(Total.length.broken., na.rm=TRUE),
    sd_length_broken = sd(Total.length.broken., na.rm=TRUE),
    se_length_broken = std.error(Total.length.broken., na.rm=TRUE),
    length_nobroken = mean(Total.length.not.broken., na.rm=TRUE),
    sd_length_nobroken = sd(Total.length.not.broken., na.rm=TRUE),
    se_length_nobroken = std.error(Total.length.not.broken., na.rm=TRUE),
    total_stem_density = mean(stem_density, na.rm=TRUE),
    sd_stem_density = sd(stem_density, na.rm=TRUE),
    se_stem_density = std.error(stem_density, na.rm=TRUE)
  )
df.summary7

ggplot(df.summary7, aes(x = sp_code, y = diam, fill=Date))  + 
  theme_classic(base_size=15)+
  geom_bar(stat="identity", position=position_dodge(), width= 0.9) +
  geom_errorbar(aes(ymin=diam-sd_diam, ymax=diam+sd_diam), width=.5,position=position_dodge(0.9))+
  scale_fill_manual(name= "Date", values = c("cadetblue1", "cadetblue2","cadetblue3","cadetblue4", "darkseagreen1", "darkseagreen2", "darkseagreen3"))+
  #ylim(0, 7.5)
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Date", y = "Stem diameter (cm)")
#facet_grid(.~location)

ggplot(df.summary7, aes(x = sp_code, y = total_stem_density, fill=Date))  + 
  theme_classic(base_size=15)+
  geom_bar(stat="identity", position=position_dodge(), width= 0.9) +
  geom_errorbar(aes(ymin=total_stem_density-sd_stem_density, ymax=total_stem_density+sd_stem_density), width=.5,position=position_dodge(0.9))+
  scale_fill_manual(name= "Date", values = c("cadetblue1", "cadetblue2","cadetblue3","cadetblue4", "darkseagreen1", "darkseagreen2", "darkseagreen3"))+
  #ylim(0, 10000)+
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Date", y = "Stem density (num. m-2")
#facet_grid(.~location)

ggplot(df.summary7, aes(x = sp_code, y = full, fill=Date))  + 
  theme_classic(base_size=15)+
  geom_bar(stat="identity", position=position_dodge(), width= 0.9) +
  geom_errorbar(aes(ymin=full-sd_full, ymax=full+sd_full), width=.5,position=position_dodge(0.9))+
  scale_fill_manual(name= "Date", values = c("cadetblue1", "cadetblue2","cadetblue3","cadetblue4", "darkseagreen1", "darkseagreen2", "darkseagreen3"))+
  #ylim(0, 7.5)
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Date", y = "full Stem density (num. m-2")
#facet_grid(.~location)


###MEANS FOR THE BIOMASS: first sum the biomass measured by layer in each plot (we will plot the global). Then obtain the mean per location
## Important to use the na.rm=TRU to remove the NA, otherwise it doesn't calculate the means

df.summary5 <- df.summary4 %>%
  group_by(Date, Code, plot, sp_code) %>%  
  summarise(
  biomass = sum(Dry.weight.g., na.rm=TRUE)
  )
df.summary5

df.summary5$biomass_m2<-(df.summary5$biomass)*25

df.summary6 <- df.summary5 %>%
  group_by(Date, sp_code) %>%  
  summarise(
    mean_biomass = mean(biomass_m2, na.rm=TRUE),
    sd_biomass = sd(biomass_m2, na.rm=TRUE),
    se_biomass = std.error(biomass_m2, na.rm=TRUE)
  )
df.summary6

ggplot(df.summary6, aes(x = sp_code, y = mean_biomass, fill=Date))  + 
  theme_classic(base_size=15)+
  geom_bar(stat="identity", position=position_dodge(), width= 0.9) +
  geom_errorbar(aes(ymin=mean_biomass-sd_biomass, ymax=mean_biomass+sd_biomass), width=.5,position=position_dodge(0.9))+
  scale_fill_manual(name= "Date", values = c("cadetblue1", "cadetblue2","cadetblue3","cadetblue4", "darkseagreen1", "darkseagreen2", "darkseagreen3"))+
  #ylim(0, 7.5)
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Date", y = "Biomass (g m-2)")
#facet_grid(.~location)

##boxplots biomass

df.summary5$sp_code <- df.summary5$plot

df.summary5$sp_code[which(df.summary5$sp_code == "and1")] <- "sali_grass" 
df.summary5$sp_code[which(df.summary5$sp_code == "and2")] <- "atri" 
df.summary5$sp_code[which(df.summary5$sp_code == "and3")] <- "sali_grass" 
df.summary5$sp_code[which(df.summary5$sp_code == "and4")] <- "spartina" 
df.summary5$sp_code[which(df.summary5$sp_code == "hol1")] <- "phragmites" 
df.summary5$sp_code[which(df.summary5$sp_code == "hol2")] <- "aster" 
df.summary5$sp_code[which(df.summary5$sp_code == "hol3")] <- "atri" 
df.summary5$sp_code[which(df.summary5$sp_code== "hol5")] <- "sali_anual" 
df.summary5$sp_code[which(df.summary5$sp_code== "hol6")] <- "19" 
df.summary5$sp_code[which(df.summary5$sp_code == "uit1")] <- "sali_grass" 
df.summary5$sp_code[which(df.summary5$sp_code == "uit2")] <- "ely" 
df.summary5$sp_code[which(df.summary5$sp_code == "uit3")] <- "ely" 
df.summary5$sp_code[which(df.summary5$sp_code == "uit4")] <- "sali_grass"
df.summary5$sp_code[which(df.summary5$sp_code == "uit5")] <- "sali_anual" 
df.summary5$sp_code[which(df.summary5$sp_code == "uit6")] <- "sali_grass" 
df.summary5$sp_code[which(df.summary5$sp_code == "zwa1")] <- "grass" 
df.summary5$sp_code[which(df.summary5$sp_code == "zwa2")] <- "suaeda" 
df.summary5$sp_code[which(df.summary5$sp_code == "zwa3")] <- "sali_grass" 
df.summary5$sp_code[which(df.summary5$sp_code == "zwa4")] <- "spartina" 
df.summary5$sp_code[which(df.summary5$sp_code == "hol4")] <- "suaeda" 
df.summary5$sp_code[which(df.summary5$sp_code== "hol5old")] <- "19" 
df.summary5$sp_code[which(df.summary5$sp_code == "hol2_aster")] <- "aster" 
df.summary5$sp_code[which(df.summary5$sp_code == "hol4_suaeda")] <- "suaeda" 

df.summary5$location <- df.summary5$plot

df.summary5$location[which(df.summary5$location == "and1")] <- "and" 
df.summary5$location[which(df.summary5$location == "and2")] <- "and" 
df.summary5$location[which(df.summary5$location == "and3")] <- "and" 
df.summary5$location[which(df.summary5$location == "and4")] <- "and" 
df.summary5$location[which(df.summary5$location == "hol1")] <- "hol" 
df.summary5$location[which(df.summary5$location == "hol2")] <- "hol" 
df.summary5$location[which(df.summary5$location == "hol3")] <- "hol" 
df.summary5$location[which(df.summary5$location== "hol5")] <- "hol" 
df.summary5$location[which(df.summary5$location== "hol6")] <- "hol" 
df.summary5$location[which(df.summary5$location == "uit1")] <- "uit" 
df.summary5$location[which(df.summary5$location == "uit2")] <- "uit" 
df.summary5$location[which(df.summary5$location == "uit3")] <- "uit" 
df.summary5$location[which(df.summary5$location == "uit4")] <- "uit" 
df.summary5$location[which(df.summary5$location == "uit5")] <- "uit" 
df.summary5$location[which(df.summary5$location == "uit6")] <- "uit_narrow" 
df.summary5$location[which(df.summary5$location == "zwa1")] <- "zwa" 
df.summary5$location[which(df.summary5$location == "zwa2")] <- "zwa" 
df.summary5$location[which(df.summary5$location == "zwa3")] <- "zwa" 
df.summary5$location[which(df.summary5$location == "zwa4")] <- "zwa" 
df.summary5$location[which(df.summary5$location == "hol4")] <- "hol" 
df.summary5$location[which(df.summary5$location== "hol5old")] <- "hol" 
df.summary5$location[which(df.summary5$location == "hol2_aster")] <- "hol" 
df.summary5$location[which(df.summary5$location == "hol4_suaeda")] <- "hol" 

df.summary5<-df.summary5[which(df.summary5$sp_code=="aster"| 
                                 df.summary5$sp_code=="atri"|
                                 df.summary5$sp_code=="ely"|
                                 df.summary5$sp_code=="grass"|
                                 df.summary5$sp_code=="phragmites"|
                                 df.summary5$sp_code=="sali_anual"|
                                 df.summary5$sp_code=="sali_grass"|
                                 df.summary5$sp_code=="spartina"|
                                 df.summary5$sp_code=="suaeda"),]


ggplot(df.summary5, aes(x = sp_code, y = biomass, col=Date), na.rm=TRUE)  + 
  theme_classic(base_size=15)+
  geom_boxplot() +
  scale_colour_manual(name= "Vegetation", values = c("plum1", "skyblue","gold","aquamarine", "violetred1", "green1", "green3","yellow4", "springgreen4" ))+
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Date", y = "Biomass")


###
# PLOTS NUMBER OF STRUCTURES
###

###Load data (number of structures per stem and the height at which structure are found)
struc = read.csv('all_vegetation_structures.csv') 

struc$No.structures.stem<-as.numeric(struc$No.structures.stem)
struc$Height.str<-as.numeric(struc$Height.str)

df.summary7<-struc

df.summary7$sp_code <- df.summary7$plot

df.summary7$sp_code[which(df.summary7$sp_code == "and1")] <- "sali_grass" 
df.summary7$sp_code[which(df.summary7$sp_code == "and2")] <- "atri" 
df.summary7$sp_code[which(df.summary7$sp_code == "and3")] <- "sali_grass" 
df.summary7$sp_code[which(df.summary7$sp_code == "and4")] <- "spartina"
df.summary7$sp_code[which(df.summary7$sp_code == "hol1")] <- "phragmites" 
df.summary7$sp_code[which(df.summary7$sp_code == "hol2")] <- "aster" 
df.summary7$sp_code[which(df.summary7$sp_code == "hol3")] <- "atri" 
df.summary7$sp_code[which(df.summary7$sp_code== "hol5")] <- "sali_anual"
df.summary7$sp_code[which(df.summary7$sp_code== "hol6")] <- "19" 
df.summary7$sp_code[which(df.summary7$sp_code == "uit1")] <- "sali_grass" 
df.summary7$sp_code[which(df.summary7$sp_code == "uit2")] <- "ely" 
df.summary7$sp_code[which(df.summary7$sp_code == "uit3")] <- "ely" 
df.summary7$sp_code[which(df.summary7$sp_code == "uit4")] <- "sali_grass" 
df.summary7$sp_code[which(df.summary7$sp_code == "uit5")] <- "sali_anual" 
df.summary7$sp_code[which(df.summary7$sp_code == "uit6")] <- "sali_grass" 
df.summary7$sp_code[which(df.summary7$sp_code == "zwa1")] <- "grass"
df.summary7$sp_code[which(df.summary7$sp_code == "zwa2")] <- "suaeda" 
df.summary7$sp_code[which(df.summary7$sp_code == "zwa3")] <- "sali_grass" 
df.summary7$sp_code[which(df.summary7$sp_code == "zwa4")] <- "spartina" 
df.summary7$sp_code[which(df.summary7$sp_code == "hol4")] <- "suaeda" 
df.summary7$sp_code[which(df.summary7$sp_code== "hol5old")] <- "19" 
df.summary7$sp_code[which(df.summary7$sp_code == "hol2_aster")] <- "aster" 
df.summary7$sp_code[which(df.summary7$sp_code == "hol4_suaeda")] <- "suaeda" 

df.summary7$location <- df.summary7$plot

df.summary7$location[which(df.summary7$location == "and1")] <- "and" 
df.summary7$location[which(df.summary7$location == "and2")] <- "and" 
df.summary7$location[which(df.summary7$location == "and3")] <- "and" 
df.summary7$location[which(df.summary7$location == "and4")] <- "and" 
df.summary7$location[which(df.summary7$location == "hol1")] <- "hol" 
df.summary7$location[which(df.summary7$location == "hol2")] <- "hol" 
df.summary7$location[which(df.summary7$location == "hol3")] <- "hol" 
df.summary7$location[which(df.summary7$location== "hol5")] <- "hol" 
df.summary7$location[which(df.summary7$location== "hol6")] <- "hol" 
df.summary7$location[which(df.summary7$location == "uit1")] <- "uit" 
df.summary7$location[which(df.summary7$location == "uit2")] <- "uit" 
df.summary7$location[which(df.summary7$location == "uit3")] <- "uit" 
df.summary7$location[which(df.summary7$location == "uit4")] <- "uit" 
df.summary7$location[which(df.summary7$location == "uit5")] <- "uit" 
df.summary7$location[which(df.summary7$location == "uit6")] <- "uit_narrow" 
df.summary7$location[which(df.summary7$location == "zwa1")] <- "zwa" 
df.summary7$location[which(df.summary7$location == "zwa2")] <- "zwa" 
df.summary7$location[which(df.summary7$location == "zwa3")] <- "zwa" 
df.summary7$location[which(df.summary7$location == "zwa4")] <- "zwa" 
df.summary7$location[which(df.summary7$location == "hol4")] <- "hol" 
df.summary7$location[which(df.summary7$location== "hol5old")] <- "hol" 
df.summary7$location[which(df.summary7$location == "hol2_aster")] <- "hol" 
df.summary7$location[which(df.summary7$location == "hol4_suaeda")] <- "hol" 


df.summary7<-df.summary7[which(df.summary7$sp_code=="aster"| 
                                 df.summary7$sp_code=="atri"|
                                 df.summary7$sp_code=="ely"|
                                 df.summary7$sp_code=="grass"|
                                 df.summary7$sp_code=="phragmites"|
                                 df.summary7$sp_code=="sali_anual"|
                                 df.summary7$sp_code=="sali_grass"|
                                 df.summary7$sp_code=="spartina"|
                                 df.summary7$sp_code=="suaeda"),]

#first we calculate the sum of structures per sample (per Code and date)
#the we do the mean per species (not distinguishing between locations, so not using the "plot" for the means but using the "sp_code")

df.summary7_1 <- df.summary7 %>%
  group_by(Date, Code, plot, sp_code) %>%  
  summarise(
    total.str = sum(No.structures.stem, na.rm=TRUE)
  )
df.summary7_1

df.summary8 <- df.summary7_1%>%
  group_by(Date, sp_code) %>%  
  summarise(
    mean_str = mean(total.str, na.rm=TRUE),
    sd_str = sd(total.str, na.rm=TRUE),
    se_str = std.error(total.str, na.rm=TRUE)
  )
df.summary8
##plot sum of the number of structures per stem (not taking into account the height), to show how the number of structures decrease during winter
ggplot(df.summary8, aes(x = sp_code, y = mean_str, fill=Date))  + 
  theme_classic(base_size=15)+
  geom_bar(stat="identity", position=position_dodge(), width= 0.9) +
  geom_errorbar(aes(ymin=mean_str-sd_str, ymax=mean_str+sd_str), width=.5,position=position_dodge(0.9))+
  scale_fill_manual(name= "Date", values = c("cadetblue1", "cadetblue2","cadetblue3","cadetblue4", "darkseagreen1", "darkseagreen2", "darkseagreen3"))+
  #ylim(0, 7.5)
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Date", y = "Number of structures per stem")
#facet_grid(.~location)


##mean of the number of structures for each height, to plot the differences between species and date
df.summary9 <- df.summary7 %>%
  group_by(Date, Code,plot,sp_code, Height.str) %>%  
  summarise(
    num.str = mean(No.structures.stem, na.rm=TRUE),
    sd_num.str = sd(No.structures.stem, na.rm=TRUE),
    se_num.str = std.error(No.structures.stem, na.rm=TRUE)
  )
df.summary9

#we bin the height data to make the plots more simple
df.summary10 <- df.summary7 %>%
  # Add a new column called 'bin': cut the initial 'carat' in bins
  mutate( bin=cut_width(Height.str, width=15, boundary=0) ) 

df.summary10$bin<-as.numeric(df.summary10$bin) #to convert the axis to numbers instead iof bins in the plots
df.summary10$bin<-as.factor(df.summary10$bin) #because we do a bocplot we conevrt again to factor, but now instead of (0-1) will be 1, etc

##mean of the number of structures for each height category, to plot the differences between species and date
df.summary9 <- df.summary10 %>%
  group_by(Date, Code,plot,sp_code, bin) %>% 
  summarise(
    num.str = mean(No.structures.stem, na.rm=TRUE),
    sd_num.str = sd(No.structures.stem, na.rm=TRUE),
    se_num.str = std.error(No.structures.stem, na.rm=TRUE)
  )
df.summary9


#final structure~height plot:
library(lemon)
str<- ggplot(na.omit(df.summary9), aes(x = bin , y = num.str), na.rm=TRUE)  + 
  theme_classic(base_size=8)+
  geom_boxplot( aes(group=bin, col=Date)) +
  #geom_errorbar(aes(ymin=num.str-sd_num.str, ymax=num.str+sd_num.str), width=.5,position=position_dodge(0.9))+
  scale_color_manual(name= "Date", values = c("cadetblue1", "cadetblue2","cadetblue3","cadetblue4", "darkseagreen1", "darkseagreen2", "darkseagreen3"))+
  #xlim(0, 50)+
  ylim(0, 7)+
  theme(axis.text.x = element_text(angle = 90))+
  labs( x= "Vegetation height (cm)", y =  "num. structures")+
  facet_rep_grid(Date~sp_code)+ #facet_rep_grip puts the axis in all the subplot, facet_grid doesn't
  coord_flip()

str

